@@ -8,20 +8,19 @@ use common::Asset;
 fn test_executing_query_with_2_files() {
     let mut client = Client::connect("localhost", 1984, "admin", "admin").unwrap();
 
-    let info = client.create("lambada", None).unwrap();
+    let info = client.create("lambada").unwrap().without_input().unwrap();
+
     assert!(info.starts_with("Database 'lambada' created"));
 
     let test_xml = Asset::get("sleeping.xml").unwrap();
-    let test_xml = std::str::from_utf8(test_xml.as_ref()).unwrap();
-    let info = client.add("sleeping", Some(test_xml)).unwrap();
+    let info = client.add("sleeping", &mut test_xml.as_ref()).unwrap();
     assert!(info.starts_with("Resource(s) added"));
 
     let test_xml = Asset::get("powder.xml").unwrap();
-    let test_xml = std::str::from_utf8(test_xml.as_ref()).unwrap();
-    let info = client.add("powder", Some(test_xml)).unwrap();
+    let info = client.add("powder", &mut test_xml.as_ref()).unwrap();
     assert!(info.starts_with("Resource(s) added"));
 
-    let mut query = client.query("count(//artikl)").unwrap();
+    let mut query = client.query(&mut "count(//artikl)".as_bytes()).unwrap();
     let result = query.execute().unwrap();
     assert_eq!(result, "3");
 
